summaryrefslogtreecommitdiff
path: root/include/cros_board_info.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/cros_board_info.h')
-rw-r--r--include/cros_board_info.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/include/cros_board_info.h b/include/cros_board_info.h
index 7650cfc078..13eff572d9 100644
--- a/include/cros_board_info.h
+++ b/include/cros_board_info.h
@@ -44,7 +44,7 @@ struct cbi_data {
/**
* Board info accessors
*
* @param version/sku_id/oem_id [OUT] Data read from EEPROM
* @return EC_SUCCESS on success or EC_ERROR_* otherwise.
* EC_ERROR_BUSY to indicate data is not ready.
*/
@@ -52,6 +52,7 @@ int cbi_get_board_version(uint32_t *version);
int cbi_get_sku_id(uint32_t *sku_id);
int cbi_get_oem_id(uint32_t *oem_id);
int cbi_get_model_id(uint32_t *id);
+int cbi_get_fw_config(uint32_t *fw_config);
/**
* Get data from CBI store
@@ -44,7 +44,7 @@ struct cbi_data {
* Board info accessors
*
- * @param version/sku_id/oem_id [OUT] Data read from EEPROM
+ * @param version/sku_id/oem_id/id/fw_config [OUT] Data read from EEPROM
* @return EC_SUCCESS on success or EC_ERROR_* otherwise.
* EC_ERROR_BUSY to indicate data is not ready.